##  Overview
To store additional information on a fact sheet, you can add the following resources to it: links, files, diagrams, and logos. To learn how to work with fact sheet resources in the application UI, see [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__storing_resources_on_fact_sheets).
In this tutorial, you'll learn how to import links as resources to application fact sheets in batch using the SAP LeanIX [Integration API](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD "Overview of the Integration API.").
By the end of this tutorial, you'll be able to:
  * Programmatically convert a CSV file into LDIF format using a Python script
  * Import links to application fact sheets using an inbound processor of the Integration API
